@@ -7,7 +7,12 @@ import pygfx
 from ..utils import parse_cmap_values
 from ._collection_base import CollectionIndexer, GraphicCollection, CollectionFeature
 from .line import LineGraphic
-from .selectors import LinearRegionSelector, LinearSelector, RectangleSelector
+from .selectors import (
+    LinearRegionSelector,
+    LinearSelector,
+    RectangleSelector,
+    PolygonSelector,
+)
 
 
 class _LineCollectionProperties:
@@ -67,7 +72,7 @@ class _LineCollectionProperties:
         """
         Get or set a cmap along the line collection.
 
-        Optionally set using a tuple ("cmap", <transform>, <alpha>) to set the transform and/or alpha.
+        Optionally set using a tuple ("cmap", <transform>) to set the transform..
         Example:
 
         line_collection.cmap = ("jet", sine_transform_vals, 0.7)
@@ -79,23 +84,20 @@ class _LineCollectionProperties:
     def cmap(self, args):
         if isinstance(args, str):
             name = args
-            transform, alpha = None, 1.0
+            transform = None
         elif len(args) == 1:
             name = args[0]
-            transform, alpha = None, None
-
+            transform = None
         elif len(args) == 2:
             name, transform = args
-            alpha = None
+        else:
+            raise ValueError(
+                "Too many values for cmap (note that alpha is deprecated, set alpha on the graphic instead)"
+            )
 
-        elif len(args) == 3:
-            name, transform, alpha = args
-
-        colors = parse_cmap_values(
+        self.colors = parse_cmap_values(
             n_colors=len(self), cmap_name=name, transform=transform
         )
-        colors[:, -1] = alpha
-        self.colors = colors
 
     @property
     def thickness(self) -> np.ndarray:
@@ -127,7 +129,6 @@ class LineCollection(GraphicCollection, _LineCollectionProperties):
         thickness: float | Sequence[float] = 2.0,
         colors: str | Sequence[str] | np.ndarray | Sequence[np.ndarray] = "w",
         uniform_colors: bool = False,
-        alpha: float = 1.0,
         cmap: Sequence[str] | str = None,
         cmap_transform: np.ndarray | List = None,
         name: str = None,
@@ -159,9 +160,6 @@ class LineCollection(GraphicCollection, _LineCollectionProperties):
             | if ``list`` of ``str``, represents color for each individual line, example ["w", "b", "r",...]
             | if ``RGBA array`` of shape [data_size, 4], represents a single RGBA array for each line
 
-        alpha: float, optional
-            alpha value for colors, if colors is a ``str``
-
         cmap: Iterable of str or str, optional
             | if ``str``, single cmap will be used for all lines
             | if ``list`` of ``str``, each cmap will apply to the individual lines
@@ -198,19 +196,19 @@ class LineCollection(GraphicCollection, _LineCollectionProperties):
         if not isinstance(thickness, (float, int)):
             if len(thickness) != len(data):
                 raise ValueError(
-                    f"len(thickness) != len(data)\n" f"{len(thickness)} != {len(data)}"
+                    f"len(thickness) != len(data)\n{len(thickness)} != {len(data)}"
                 )
 
         if names is not None:
             if len(names) != len(data):
                 raise ValueError(
-                    f"len(names) != len(data)\n" f"{len(names)} != {len(data)}"
+                    f"len(names) != len(data)\n{len(names)} != {len(data)}"
                 )
 
         if metadatas is not None:
             if len(metadatas) != len(data):
                 raise ValueError(
-                    f"len(metadata) != len(data)\n" f"{len(metadatas)} != {len(data)}"
+                    f"len(metadata) != len(data)\n{len(metadatas)} != {len(data)}"
                 )
 
         if kwargs_lines is not None:
@@ -248,7 +246,7 @@ class LineCollection(GraphicCollection, _LineCollectionProperties):
         else:
             if isinstance(colors, np.ndarray):
                 # single color for all lines in the collection as RGBA
-                if colors.shape == (4,):
+                if colors.shape in [(3,), (4,)]:
                     single_color = True
 
                 # colors specified for each line as array of shape [n_lines, RGBA]
@@ -263,8 +261,7 @@ class LineCollection(GraphicCollection, _LineCollectionProperties):
 
             elif isinstance(colors, str):
                 if colors == "random":
-                    colors = np.random.rand(len(data), 4)
-                    colors[:, -1] = alpha
+                    colors = np.random.rand(len(data), 3)
                     single_color = False
                 else:
                     # parse string color
@@ -381,9 +378,6 @@ class LineCollection(GraphicCollection, _LineCollectionProperties):
 
         self._plot_area.add_graphic(selector, center=False)
 
-        # place selector above this graphic
-        selector.offset = selector.offset + (0.0, 0.0, self.offset[-1] + 1)
-
         return selector
 
     def add_linear_region_selector(
@@ -438,16 +432,13 @@ class LineCollection(GraphicCollection, _LineCollectionProperties):
 
         self._plot_area.add_graphic(selector, center=False)
 
-        # place selector below this graphic
-        selector.offset = selector.offset + (0.0, 0.0, self.offset[-1] - 1)
-
         # PlotArea manages this for garbage collection etc. just like all other Graphics
         # so we should only work with a proxy on the user-end
         return selector
 
     def add_rectangle_selector(
         self,
-        selection: tuple[float, float, float, float] = None,
+        selection: tuple[float, float, float] = None,
         **kwargs,
     ) -> RectangleSelector:
         """
@@ -486,6 +477,43 @@ class LineCollection(GraphicCollection, _LineCollectionProperties):
 
         return selector
 
+    def add_polygon_selector(
+        self,
+        selection: List[tuple[float, float]] = None,
+        **kwargs,
+    ) -> PolygonSelector:
+        """
+        Add a :class:`.PolygonSelector`. Selectors are just ``Graphic`` objects, so you can manage,
+        remove, or delete them from a plot area just like any other ``Graphic``.
+
+        Parameters
+        ----------
+        selection: List of positions, optional
+            Initial points for the polygon. If not given or None, you'll start drawing the selection (clicking adds points to the polygon).
+        """
+        bbox = self.world_object.get_world_bounding_box()
+
+        xdata = np.array(self.data[:, 0])
+        xmin, xmax = (np.nanmin(xdata), np.nanmax(xdata))
+
+        ydata = np.array(self.data[:, 1])
+        ymin = np.floor(ydata.min()).astype(int)
+
+        ymax = np.ptp(bbox[:, 1])
+
+        limits = (xmin, xmax, ymin - (ymax * 1.5 - ymax), ymax * 1.5)
+
+        selector = PolygonSelector(
+            selection,
+            limits,
+            parent=self,
+            **kwargs,
+        )
+
+        self._plot_area.add_graphic(selector, center=False)
+
+        return selector
+
     def _get_linear_selector_init_args(self, axis, padding):
         # use bbox to get size and center
         bbox = self.world_object.get_world_bounding_box()
@@ -526,7 +554,6 @@ class LineStack(LineCollection):
         data: List[np.ndarray],
         thickness: float | Iterable[float] = 2.0,
         colors: str | Iterable[str] | np.ndarray | Iterable[np.ndarray] = "w",
-        alpha: float = 1.0,
         cmap: Iterable[str] | str = None,
         cmap_transform: np.ndarray | List = None,
         name: str = None,
@@ -560,9 +587,6 @@ class LineStack(LineCollection):
             | if ``list`` of ``str``, represents color for each individual line, example ["w", "b", "r",...]
             | if ``RGBA array`` of shape [data_size, 4], represents a single RGBA array for each line
 
-        alpha: float, optional
-            alpha value for colors, if colors is a ``str``
-
         cmap: Iterable of str or str, optional
             | if ``str``, single cmap will be used for all lines
             | if ``list`` of ``str``, each cmap will apply to the individual lines
@@ -604,7 +628,6 @@ class LineStack(LineCollection):
             data=data,
             thickness=thickness,
             colors=colors,
-            alpha=alpha,
             cmap=cmap,
             cmap_transform=cmap_transform,
             name=name,
