@@ -543,6 +543,11 @@ class Figure:
         """show/hide tooltips for all graphics"""
         return self._show_tooltips
 
+    @property
+    def animations(self) -> dict[str, list[callable]]:
+        """Returns a dictionary of 'pre' and 'post' animation functions."""
+        return {"pre": self._animate_funcs_pre, "post": self._animate_funcs_post}
+
     @show_tooltips.setter
     def show_tooltips(self, val: bool):
         self._show_tooltips = val
@@ -560,12 +565,19 @@ class Figure:
         # draw the underlay planes
         self.renderer.render(self._underlay_scene, self._underlay_camera, flush=False)
 
+        # With new pygfx' blending, the depth buffer is only cleared after each flush, we need a manual depth
+        # clear to erase the depth values set by the underlay.
+        if hasattr(self.renderer, "clear"):
+            self.renderer.clear(depth=True)
+
         # call the animation functions before render
         self._call_animate_functions(self._animate_funcs_pre)
         for subplot in self:
             subplot._render()
 
         # overlay render pass
+        if hasattr(self.renderer, "clear"):
+            self.renderer.clear(depth=True)
         self.renderer.render(self._overlay_scene, self._overlay_camera, flush=False)
 
         self.renderer.flush()
@@ -585,6 +597,7 @@ class Figure:
         self,
         autoscale: bool = True,
         maintain_aspect: bool = None,
+        axes_visible: bool = True,
         sidecar: bool = False,
         sidecar_kwargs: dict = None,
     ):
@@ -599,6 +612,9 @@ class Figure:
         maintain_aspect: bool, default ``True``
             maintain aspect ratio
 
+        axes_visible: bool, default ``True``
+            show axes
+
         sidecar: bool, default ``True``
             display plot in a ``jupyterlab-sidecar``, only in jupyter
 
@@ -637,6 +653,11 @@ class Figure:
                     _maintain_aspect = maintain_aspect
                 subplot.auto_scale(maintain_aspect=maintain_aspect)
 
+        # set axes visibility if False
+        if not axes_visible:
+            for subplot in self:
+                subplot.axes.visible = False
+
         # parse based on canvas type
         if self.canvas.__class__.__name__ == "JupyterRenderCanvas":
             if sidecar:
@@ -749,6 +770,37 @@ class Figure:
         if func in self._animate_funcs_post:
             self._animate_funcs_post.remove(func)
 
+    def clear_animations(self, removal: str = None):
+        """
+        Remove animation functions.
+
+        Parameters
+        ----------
+        removal: str, default ``None``
+            The type of animation functions to clear. One of 'pre' or 'post'. If `None`, removes all animation
+            functions.
+        """
+        if removal is None:
+            # remove all
+            for func in self._animate_funcs_pre:
+                self._animate_funcs_pre.remove(func)
+
+            for func in self._animate_funcs_post:
+                self._animate_funcs_post.remove(func)
+        elif removal == "pre":
+            # only pre
+            for func in self._animate_funcs_pre:
+                self._animate_funcs_pre.remove(func)
+        elif removal == "post":
+            # only post
+            for func in self._animate_funcs_post:
+                self._animate_funcs_post.remove(func)
+        else:
+            raise ValueError(
+                f"Animation type: {removal} must be one of 'pre' or 'post'. To remove all animation "
+                f"functions, pass `type=None`"
+            )
+
     def clear(self):
         """Clear all Subplots"""
         for subplot in self:
